==> biosignalEMG_1.0.tar.gz: biosignalEMG/man/emg.Rd <==
\name{emg}
\alias{emg}
\alias{plot.emg}
\alias{print.emg}
\alias{summary.emg}

\title{
EMG object
}
\description{
Creates an \sQuote{emg} object to store an EMG signal.
}
\usage{
emg(data, samplingrate = 0, units = "", data.name = "")

\method{plot}{emg}(x, type = "l", timeunits = c("seconds", "samples"), add = FALSE, ...)
\method{print}{emg}(x, ...)
\method{summary}{emg}(object, ...)
}
\arguments{
  \item{data}{
a data vector containing observed data.
}
  \item{samplingrate}{
number of samples carried per second, measured in Hz. A value of 0 indicates that this value is missing or unknown.
}
  \item{units}{
a character vector specifying the units (usually \sQuote{mV}) of the EMG data.
}
  \item{data.name}{
a string specifying the name of the variable which appears on the plots. If empty or not
provided is taken from the object given as data.
}
  \item{x, object}{
an object of class \sQuote{emg}.
}
  \item{type}{
what type of plot should be drawn. See \code{\link[graphics]{plot}} for details.
}
  \item{timeunits}{
a character vector specifying the units (samples or seconds) for the time axis.
}
  \item{add}{
logical; if \code{TRUE} add to an already existing plot; if \code{FALSE} start a new plot.
}
  \item{\dots}{
additional arguments to be passed to the generic function.
}
}
\value{
returns an object of class \sQuote{emg} which is a list with components:
\item{\code{values}}{a copy of \code{data}} 
\item{\code{units}}{the \code{units} argument}
\item{\code{samplingrate}}{the \code{samplingrate} argument}
\item{\code{data.name}}{the \code{data.name} argument}
}
\references{
Konrad P. (2005) The ABC of EMG: A Practical Introduction to Kinesiological
Electromyography. Version 1.0, Noraxon INC. USA 

Winter D.A., Rau G., Kadefors R., Broman H., Deluca C.J. (1980) Units, Terms, and Sandards in the Reporting of
EMG Research: A Report by the AdHoc Committee of the International Society of Electrophysiology
and Kinesiology.
}
\author{
Antonio Guerrero \email{jaguerrero@correo.uaa.mx}
}
\note{
An \sQuote{emg} object can only handle a single-channel EMG signal.
}

\seealso{
\code{\link{iemg}}, \code{\link{eaemg}}
}
\examples{
## Creates a random vector to simulate an EMG signal
x <- rnorm(10000, 0, 1)
## Creates an 'emg' object to store x 
emg1 <- emg(x, samplingrate=1000, units="mV", data.name="")
\dontshow{print.emg(emg1)}
## Summarize and visualize the data 
summary(emg1)
plot(emg1, main="Simulated EMG")

}
\keyword{graphs}
\keyword{manip}

==> biosignalEMG_1.0.3.tar.gz: biosignalEMG/man/emg.Rd <==
\name{emg}
\alias{emg}
\alias{plot.emg}
\alias{print.emg}
\alias{summary.emg}

\title{
EMG object
}
\description{
Creates an \sQuote{emg} object to store an EMG signal.
}
\usage{
emg(data, samplingrate = 0, units = "", data.name = "")

\method{plot}{emg}(x, type = "l", timeunits = c("seconds", "samples"), add = FALSE, ...)
\method{print}{emg}(x, ...)
\method{summary}{emg}(object, ...)
}
\arguments{
  \item{data}{
a data vector containing observed data.
}
  \item{samplingrate}{
number of samples carried per second, measured in Hz. A value of 0 indicates that this value is missing or unknown.
}
  \item{units}{
a character vector specifying the units (usually \sQuote{mV}) of the EMG data.
}
  \item{data.name}{
a string specifying the name of the variable which appears on the plots. If empty or not
provided is taken from the object given as data.
}
  \item{x, object}{
an object of class \sQuote{emg}.
}
  \item{type}{
what type of plot should be drawn. See \code{\link[graphics]{plot}} for details.
}
  \item{timeunits}{
a character vector specifying the units (samples or seconds) for the time axis.
}
  \item{add}{
logical; if \code{TRUE} add to an already existing plot; if \code{FALSE} start a new plot.
}
  \item{\dots}{
additional arguments to be passed to the generic function.
}
}
\value{
returns an object of class \sQuote{emg} which is a list with components:
\item{\code{values}}{a copy of \code{data}} 
\item{\code{units}}{the \code{units} argument}
\item{\code{samplingrate}}{the \code{samplingrate} argument}
\item{\code{data.name}}{the \code{data.name} argument}
}
\references{
Konrad P. (2005) The ABC of EMG: A Practical Introduction to Kinesiological
Electromyography. Version 1.0, Noraxon INC. USA 

Winter D.A., Rau G., Kadefors R., Broman H., Deluca C.J. (1980) Units, Terms, and Sandards in the Reporting of
EMG Research: A Report by the AdHoc Committee of the International Society of Electrophysiology
and Kinesiology.
}
\author{
J.A. Guerrero \email{jaguerrero@correo.uaa.mx}
}
\note{
An \sQuote{emg} object can only handle a single-channel EMG signal.
}

\seealso{
\code{\link{iemg}}, \code{\link{eaemg}}
}
\examples{
## Creates a random vector to simulate an EMG signal
x <- rnorm(10000, 0, 1)
## Creates an 'emg' object to store x 
emg1 <- emg(x, samplingrate=1000, units="mV", data.name="")
\dontshow{print.emg(emg1)}
## Summarize and visualize the data 
summary(emg1)
plot(emg1, main="Simulated EMG")

}
\keyword{graphs}
\keyword{manip}
